==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Δημιουργία υπολογιστικού φύλλου</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Δημιουργήστε ένα νέο υπολογιστικό φύλλο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Στοίχιση κάτω</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Στοίχιση κάτω τα περιεχόμενα του επιλεγμένου κελιού</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Στοίχιση στο κέντρο</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Κέντρο-ευθυγράμμιση των περιεχομένων του επιλεγμένου κελιού</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Στοίχιση Αριστερά</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation type="unfinished">Left-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Στοίχιση Δεξιά</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation type="unfinished">Right-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Πλήρης στοίχιση επάνω</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Στοίχιση επάνω περιεχόμενα του επιλεγμένου κελιού</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Κάθετα κέντρο στοίχιση</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Περιεχόμενα κέντρο στοίχιση κατακόρυφα του επιλεγμένου κελιού</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Εξαγωγή υπολογιστικού φύλλου</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation type="unfinished">Export spreadsheet to CSV file</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation type="unfinished">Import spreadsheet</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation type="unfinished">Import CSV file into spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Συγχώνευση κελιών</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Συγχώνευση των επιλεγμένων κελιών σε υπολογιστικό φύλλο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Ορισμός ψευδωνύμου</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Ορισμός ψευδωνύμου για το επιλεγμένο κελί</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Διαίρεση κελιού</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation type="unfinished">Split previously merged cells in spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Έντονη γραφή</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Ορίσετε τολμηρό κείμενο των επιλεγμένων κελιών</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>πλαγιο κειμενο</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation type="unfinished">Set italic text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation type="unfinished">Underline text</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation type="unfinished">Set underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Επιλογή</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Ιδιότητες κελιών</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp; Χρώμα</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Κείμενο</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Φόντο</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>Εναρμόνιση</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Αριστερά</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Κέντρο</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Δεξιά</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Κορυφή</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Κάτω</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp; Στυλ</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Έντονοι χαρακτήρες</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Πλάγια</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Υπογραμμισμένοι χαρακτήρες</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>Μονάδα επίδειξης</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation type="unfinished">Unit string</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation type="unfinished">A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Ψευδώνυμο για αυτό το κελί</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Όλα (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Εισαγωγή αρχείου</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Εξαγωγή αρχείου</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Περιεχόμενα του κελιού</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation type="unfinished">Show spreadsheet</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Μαύρο</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Λευκό</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Κοκκινο</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Σκούρο κόκκινο</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Πράσινο</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Σκούρο πράσινο</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Μπλε</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Σκούρο μπλε</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Κυανές</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Σκούρο κυανό</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Πορφυρό</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Σκούρο μαζέντα</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Κίτρινο</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Σκούρο κίτρινο</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Γκρί</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Σκούρο γκρι</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Ανοιχτό γκρι</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Επιλογή</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Μορφή</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Περιεχόμενα</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Ανώνυμο</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Εισαγωγή γραμμών</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Καταργήσετε γραμμές</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Εισαγωγή στηλών</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Κατάργηση στηλών</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Ιδιότητες...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό φύλλο</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Δημιουργία υπολογιστικού φύλλου</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Δημιουργία ενός νέου υπολογιστικού φύλλου</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Στοίχιση κάτω</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Στοίχιση των περιεχομένων των επιλεγμένων κελιών στο κάτω άκρο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Στοίχιση στο κέντρο</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Στοίχιση των περιεχομένων των επιλεγμένων κελιών στο κέντρο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Στοίχιση Αριστερά</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Στοίχιση των περιεχομένων των επιλεγμένων κελιών στα αριστερά</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Στοίχιση Δεξιά</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Στοίχιση των περιεχομένων των επιλεγμένων κελιών στα δεξιά</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Στοίχιση πάνω</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Στοίχιση των περιεχομένων των επιλεγμένων κελιών στο πάνω άκρο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Κατακόρυφη στοίχιση στο κέντρο</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Κατακόρυφη στοίχιση των περιεχομένων των επιλεγμένων κελιών στο κέντρο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Εξαγωγή υπολογιστικού φύλλου</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Εξαγωγή υπολογιστικού φύλλου σε αρχείο CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Εισαγωγή υπολογιστικού φύλλου</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Εισαγωγή αρχείου CSV στο υπολογιστικό φύλλο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Συγχώνευση κελιών</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Συγχώνευση επιλεγμένων κελιών στο υπολογιστικό φύλλο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Ορισμός ψευδωνύμου</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Ορισμός ψευδωνύμου για το επιλεγμένο κελί</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Διαχωρισμός κελιού</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Διαχωρισμός των κελιών που είχαν προηγουμένως συγχωνευτεί στο υπολογιστικό φύλλο</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Έντονη γραφή</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Ορισμός έντονης γραφής στα επιλεγμένα κελιά</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Πλάγια γραφή</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Ορισμός πλάγιας γραφής στα επιλεγμένα κελιά</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Υπογράμμιση κειμένου</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Ορισμός υπογράμμισης κειμένου σε επιλεγμένα κελιά</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Επιλογή</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Ιδιότητες κελιών</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>Χρώμα</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Κείμενο</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Υπόβαθρο</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>Στοίχιση</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Αριστερά</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Κέντρο</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Δεξιά</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Πάνω</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Κάτω</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>Τύπος μορφοποίησης</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Έντονη γραφή</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Πλάγια γραφή</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Υπογράμμιση</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>Μονάδα εμφάνισης</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Συμβολοσειρά μονάδας</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>Ψευδώνυμο</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Ψευδώνυμο για αυτό το κελί</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Όλα (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Εισαγωγή αρχείου</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Εξαγωγή αρχείου</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Περιεχόμενα κελιού</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Εμφάνιση υπολογιστικού φύλλου</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Ορισμός χρώματος προσκηνίου κελιών</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Ορίζει το χρώμα προσκηνίου κελιών του Υπολογιστικού Φύλλου</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Ορισμός χρώματος υποβάθρου κελιών</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Ορίζει το χρώμα υποβάθρου κελιών του Υπολογιστικού Φύλλου</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Μαύρο</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Λευκό</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Κόκκινο</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Σκούρο κόκκινο</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Πράσινο</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Σκούρο πράσινο</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Μπλε</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Σκούρο μπλε</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Κυανό</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Σκούρο κυανό</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Πορφυρό</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Σκούρο πορφυρό</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Κίτρινο</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Σκούρο κίτρινο</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Γκρι</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Σκούρο γκρι</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Ανοιχτό γκρι</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Επιλογή</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Μορφή</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>Περιεχόμενα</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Ανώνυμο</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Εισαγωγή σειρών</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Αφαίρεση σειρών</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Εισαγωγή στηλών</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Αφαίρεση στηλών</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Ιδιότητες...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Υπολογιστικό Φύλλο</translation>
    </message>
  </context>
</TS>
